@@ -682,7 +682,7 @@ void DiscoverObject::rebootNow()
     setAboutToReboot();
 
     QDBusMessage method;
-    if (s_weAreOnPlasma) {
+    if (*s_weAreOnPlasma) {
         method = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Shutdown"),
                                                 QStringLiteral("/Shutdown"),
                                                 QStringLiteral("org.kde.Shutdown"),
@@ -709,11 +709,11 @@ void DiscoverObject::shutdownNow()
     setAboutToPowerOff();
 
     QDBusMessage method;
-    if (s_weAreOnPlasma) {
-        auto method = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Shutdown"),
-                                                     QStringLiteral("/Shutdown"),
-                                                     QStringLiteral("org.kde.Shutdown"),
-                                                     shouldRebootFirst ? QStringLiteral("logoutAndReboot") : QStringLiteral("logoutAndShutdown"));
+    if (*s_weAreOnPlasma) {
+        method = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Shutdown"),
+                                                QStringLiteral("/Shutdown"),
+                                                QStringLiteral("org.kde.Shutdown"),
+                                                shouldRebootFirst ? QStringLiteral("logoutAndReboot") : QStringLiteral("logoutAndShutdown"));
     } else {
         method = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.login1"),
                                                 QStringLiteral("/org/freedesktop/login1"),
