@@ -10,16 +10,16 @@
 #include <AppStreamQt/image.h>
 #include <AppStreamQt/pool.h>
 #include <QColor>
-#include <QCoroTask>
 #include <QList>
 #include <QUrl>
 #include <resources/AbstractResource.h>
 
+#include "AppStreamConcurrentPool.h"
 #include "discovercommon_export.h"
 
 namespace AppStreamUtils
 {
-DISCOVERCOMMON_EXPORT QUrl imageOfKind(const QList<AppStream::Image> &images, AppStream::Image::Kind kind);
+DISCOVERCOMMON_EXPORT AppStream::Image imageOfKind(const QList<AppStream::Image> &images, AppStream::Image::Kind kind);
 
 DISCOVERCOMMON_EXPORT QString changelogToHtml(const AppStream::Component &appdata);
 
@@ -39,7 +39,8 @@ DISCOVERCOMMON_EXPORT QString versionString(const QString &version, const AppStr
 DISCOVERCOMMON_EXPORT QString contentRatingDescription(const AppStream::Component &appdata);
 DISCOVERCOMMON_EXPORT uint contentRatingMinimumAge(const AppStream::Component &appdata);
 
-DISCOVERCOMMON_EXPORT QCoro::Task<AppStream::ComponentBox> componentsByCategoriesTask(AppStream::Pool *pool, Category *cat, AppStream::Bundle::Kind kind);
+DISCOVERCOMMON_EXPORT QFuture<AppStream::ComponentBox>
+componentsByCategoriesTask(AppStream::ConcurrentPool *pool, const std::shared_ptr<Category> &cat, AppStream::Bundle::Kind kind);
 
 DISCOVERCOMMON_EXPORT bool kIconLoaderHasIcon(const QString &name);
 }
