@@ -6,6 +6,8 @@
 
 #pragma once
 
+#include "DiscoverConfig.h"
+
 #include <QObject>
 #include <QPair>
 #include <QVariantList>
@@ -125,7 +127,6 @@ class DISCOVERCOMMON_EXPORT AbstractResourcesBackend : public QObject
     Q_PROPERTY(int updatesCount READ updatesCount NOTIFY updatesCountChanged)
     Q_PROPERTY(int fetchingUpdatesProgress READ fetchingUpdatesProgress NOTIFY fetchingUpdatesProgressChanged)
     Q_PROPERTY(bool hasSecurityUpdates READ hasSecurityUpdates NOTIFY updatesCountChanged)
-    Q_PROPERTY(bool isFetching READ isFetching NOTIFY fetchingChanged)
     Q_PROPERTY(bool hasApplications READ hasApplications CONSTANT)
 
     Q_MOC_INCLUDE("ReviewsBackend/AbstractReviewsBackend.h")
@@ -143,7 +144,7 @@ public:
     virtual bool isValid() const = 0;
 
     struct Filters {
-        Category *category = nullptr;
+        std::shared_ptr<Category> category = nullptr;
         AbstractResource::State state = AbstractResource::Broken;
         QString mimetype;
         QString search;
@@ -195,11 +196,6 @@ public:
         return false;
     }
 
-    /**
-     * Tells whether the backend is fetching resources
-     */
-    virtual bool isFetching() const = 0;
-
     /**
      * @returns the appstream ids that this backend extends
      */
@@ -221,7 +217,7 @@ public:
     /**
      * @returns the root category tree
      */
-    virtual QVector<Category *> category() const
+    virtual QList<std::shared_ptr<Category>> category() const
     {
         return {};
     }
@@ -231,7 +227,7 @@ public:
         return false;
     }
 
-    virtual int fetchingUpdatesProgress() const;
+    virtual int fetchingUpdatesProgress() const = 0;
 
     /**
      * @returns how much this backend should influence the global fetching progress.
@@ -297,7 +293,7 @@ Q_SIGNALS:
     /**
      * Notify of a change in the backend
      */
-    void fetchingChanged();
+    void contentsChanged();
 
     /**
      * This should be emitted when the number of upgradeable packages changed.
@@ -319,6 +315,13 @@ Q_SIGNALS:
     void inlineMessageChanged(const QSharedPointer<InlineMessage> &inlineMessage);
     void fetchingUpdatesProgressChanged();
 
+    /**
+     * isValid will now return false
+     *
+     * A backend cannot become valid in its lifetime.
+     */
+    void invalidated();
+
 private:
     QString m_name;
 };
@@ -340,7 +343,7 @@ public:
     class ClassName##Factory : public AbstractResourcesBackendFactory                                                                                          \
     {                                                                                                                                                          \
         Q_OBJECT                                                                                                                                               \
-        Q_PLUGIN_METADATA(IID "org.kde.muon.AbstractResourcesBackendFactory")                                                                                  \
+        Q_PLUGIN_METADATA(IID DISCOVER_PLUGIN_IID)                                                                                                             \
         Q_INTERFACES(AbstractResourcesBackendFactory)                                                                                                          \
     public:                                                                                                                                                    \
         QVector<AbstractResourcesBackend *> newInstance(QObject *parent, const QString &name) const override                                                   \
@@ -351,4 +354,4 @@ public:
         }                                                                                                                                                      \
     };
 
-Q_DECLARE_INTERFACE(AbstractResourcesBackendFactory, "org.kde.muon.AbstractResourcesBackendFactory")
+Q_DECLARE_INTERFACE(AbstractResourcesBackendFactory, DISCOVER_PLUGIN_IID)
